<!--- app-name: Apache -->

# External Secrets Module Chart

## TL;DR

## Introduction

## Prerequisites

- Kubernetes 1.19+
- Helm 3.2.0+

## Using the Chart

## Parameters

### Global parameters

| Name                            | Description                                                                                                 | Value              |
| ------------------------------- | ----------------------------------------------------------------------------------------------------------- | ------------------ |
| `global.chartNameOverride`      | Overrides the chart name.                                                                                   | `""`               |
| `global.releaseNameOverride`    | Overrides the release name.                                                                                 | `""`               |
| `global.tags`                   | Define common tags for all IAC and app resources generated by this chart.                                   | `{}`               |
| `global.labels`                 | Define common labels for all IAC and app resources generated by this chart.                                 | `{}`               |
| `global.annotations`            | Define common annotations for all IAC and app resources generated by this chart.                            | `{}`               |
| `global.providerConfigRef.name` | Default crossplane provider all resources generated for crossplane.                                         | `aws-provider`     |
| `global.awsAccountId`           | Default aws account id for crossplane aws provider resources. Quotes are important, value must be a string. | `0123456789`       |
| `global.awsRegion`              | Default aws region for crossplane aws provider resources.                                                   | `us-west-2`        |
| `global.eksHash`                | Default EKS cluster hash for relevant crossplane resources such as IAM Role.                                | `XXXXX`            |
| `global.secretStoreNamespace`   | (Deprecated) Deploy external-secret store configs to different namespace than helm chart target namespace.  | `infra-argo-cd`    |
| `global.deploymentName`         | Deployment name used as fullnameoverride for upstream chart.                                                | `external-secrets` |


### Dependency: external-secrets upstream helm chart parameters.

| Name                                                                      | Description                                                                                                                          | Value              |
| ------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------------ | ------------------ |
| `external-secrets.enabled`                                                | Toggle for enabling or disabling upstream chart templates.                                                                           | `false`            |
| `external-secrets.replicaCount`                                           | Default minimum replicas for app.                                                                                                    | `2`                |
| `external-secrets.fullnameOverride`                                       | Default full name override for upstream chart. This is needed to stop upstream chart from hitting the 63 char limit for object names | `external-secrets` |
| `external-secrets.installCRDs`                                            | Install CRDs with helm chart.                                                                                                        | `true`             |
| `external-secrets.metrics.service.enabled`                                | Toggle for metrics service.                                                                                                          | `false`            |
| `external-secrets.serviceMonitor.enabled`                                 | Toggle for serviceMonitor service.                                                                                                   | `false`            |
| `external-secrets.serviceMonitor.additionalLabels.release`                | Monitoring service label filter.                                                                                                     | `monitoring`       |
| `external-secrets.webhook.metrics.service.enabled`                        | Toggle for webhook metrics service.                                                                                                  | `true`             |
| `external-secrets.webhook.serviceMonitor.enabled`                         | Toggle for webhook serviceMonitor service.                                                                                           | `false`            |
| `external-secrets.webhook.serviceMonitor.additionalLabels.release`        | Monitoring service label filter.                                                                                                     | `monitoring`       |
| `external-secrets.certController.metrics.service.enabled`                 | Toggle for certController metrics service.                                                                                           | `false`            |
| `external-secrets.certController.serviceMonitor.enabled`                  | Toggle for certController serviceMonitor service.                                                                                    | `false`            |
| `external-secrets.certController.serviceMonitor.additionalLabels.release` | Monitoring service label filter.                                                                                                     | `monitoring`       |


### Dependency: crossplane aws iam resources parameters

| Name                                                                                      | Description                                                                                                     | Value                                                                                                 |
| ----------------------------------------------------------------------------------------- | --------------------------------------------------------------------------------------------------------------- | ----------------------------------------------------------------------------------------------------- |
| `crossplane-aws-iam.enabled`                                                              | Toggle for enabling or disabling upstream chart templates.                                                      | `false`                                                                                               |
| `crossplane-aws-iam.deletionPolicy`                                                       | Crossplane will delete or orphan resource when helm chart is uninstalled. Allowed values: `Delete` or `Orphan`. | `Delete`                                                                                              |
| `crossplane-aws-iam.Policy.items._.deletionPolicy`                                        | Overrides crossplane-aws-iam.deletionPolicy value.                                                              | `Delete`                                                                                              |
| `crossplane-aws-iam.Policy.items._.annotations.crossplane.io/external-name`               | AWS resource name to import if exists.                                                                          | `arn:aws:iam::{{ .Values.global.awsAccountId }}:policy/{{ include "common-gitops.names.release" . }}` |
| `crossplane-aws-iam.Policy.items._.forProvider.description`                               | AWS resource description.                                                                                       | `IAM Policy for external secrets IAM role to access aws secret manager resources`                     |
| `crossplane-aws-iam.Role.items._.deletionPolicy`                                          | Overrides crossplane-aws-iam.deletionPolicy value.                                                              | `Delete`                                                                                              |
| `crossplane-aws-iam.Role.items._.annotations.crossplane.io/external-name`                 | AWS resource name to import if exists.                                                                          | `{{ include "common-gitops.names.release" . }}`                                                       |
| `crossplane-aws-iam.RolePolicyAttachment.items._.deletionPolicy`                          | Overrides crossplane-aws-iam.deletionPolicy value.                                                              | `Delete`                                                                                              |
| `crossplane-aws-iam.RolePolicyAttachment.items._.annotations.crossplane.io/external-name` | AWS resource name to import if exists.                                                                          | `{{ include "common-gitops.names.release" . }}`                                                       |
| `crossplane-aws-iam.RolePolicyAttachment.items._.forProvider.policyArnRef.name`           | Reference to the Policy resource created by this helm chart.                                                    | `{{ include "common-gitops.names.release" . }}`                                                       |
| `crossplane-aws-iam.RolePolicyAttachment.items._.forProvider.roleNameRef.name`            | Reference to the Role resource created by this helm chart.                                                      | `{{ include "common-gitops.names.release" . }}`                                                       |


### Addons: Addon template parameters

| Name                                    | Description                                     | Value   |
| --------------------------------------- | ----------------------------------------------- | ------- |
| `AWSExternalSecret.enabled`             | Toggle for enabling or disabling resource type. | `false` |
| `VclusterExternalSecret.enabled`        | Toggle for enabling or disabling resource type. | `false` |
| `EksClusterExternalSecret.enabled`      | Toggle for enabling or disabling resource type. | `false` |
| `ExternalSecretRole.enabled`            | Toggle for enabling or disabling resource type. | `false` |
| `ExternalSecretRoleBinding.enabled`     | Toggle for enabling or disabling resource type. | `false` |
| `ClusterSecretStore.enabled`            | Toggle for enabling or disabling resource type. | `false` |
| `SecretStore.enabled`                   | Toggle for enabling or disabling resource type. | `false` |
| `ExternalSecretsServiceAccount.enabled` | Toggle for enabling or disabling resource type. | `false` |


## Configuration and installation details


## Troubleshooting


## Notable changes
